rai\_toolbox.datasets.CIFAR10C
==============================

.. currentmodule:: rai_toolbox.datasets

.. autoclass:: CIFAR10C

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CIFAR10C.__init__
   
   
   